ThemeEngine

Struct ThemeEngine 

pub struct ThemeEngine { /* private fields */ }

Implementations

Source

impl ThemeEngine

pub fn new_with_theme(theme: &Theme) -> ThemeEngineResult<Self>

Instantiates a new ThemeEngine and sets the provided theme as the current one. This is useful for restoring a user’s theme preference across sessions.

pub fn new() -> ThemeEngineResult<Self>

pub fn reset_current_theme(&self)

pub fn apply(&self, theme: &Theme)

pub fn apply_no_set(&self, theme: &Theme)

Apply the given theme without setting current_theme to it. This is useful for previewing the theme and subsequently restoring the previously selected one.

pub fn current_theme_name(&self) -> String

Retrieves the current theme name. This is useful for saving the theme preference across sessions.

pub fn theme_chooser_widget(themes: &[Theme]) -> (Box, ListBox)

Creates a theme chooser widget consisting of a gtk::ListBox inside a adw::Clamp inside a gtk::ScrolledWindow. The ListBox is inert and requires connecting its signals to be functional, that’s why it’s returned along with the parent.

The return type is a tuple of the parent gtk::Box, and the child gtk::ListBox so that the consumer can connect to its signals and read its state easily.

Using this method is not recommended. It’s preferable to use Self::theme_chooser_dialog instead.

pub fn theme_chooser_dialog(&self, themes: &[Theme]) -> Dialog

Creates a ready to use adw::Dialog that allows to choose and set a theme. It must be provided with a valid list of themes.

It’s important that the theme names are unique, otherwise if two themes are homonymous only the first one will be used.

There is no inherent mechanism to save the theme preference, which is instead delegated to the consumer.