Theme

Struct Theme 

pub struct Theme {
    pub name: String,
    pub is_system: bool,
    pub colors: HashMap<ColorName, ThemeColor>,
}
A theme or color scheme represents a homogeneous combination of colors to applly to an application.

Each color scheme must have a unique name that identifies it.

The default Theme has no defined colors and has is_system set to true to indicate that it’s a theme that follows the system wide color scheme.

Fields

name: String

Unique name for the theme

is_system: bool

Indicates that the Theme has no colors set and therefore follows the system wide color scheme.

colors: HashMap<ColorName, ThemeColor>

Implementations

Source

impl Theme

pub fn new_from_iter<I: IntoIterator<Item = (ColorName, ThemeColor)>>( name: String, colors: I, ) -> Self

pub fn new(name: String, colors: HashMap<ColorName, ThemeColor>) -> Self

pub fn to_css(&self, variant: ThemeColorVariant) -> String

pub fn get_provider(&self, variant: ThemeColorVariant) -> CssProvider

pub fn action_row(&self) -> ActionRow

pub fn default_themes() -> Vec<Self>

Returns a list of built-in themes. Without any additional feature flags this will return an empty list.