pub struct Theme {
pub name: String,
pub is_system: bool,
pub colors: HashMap<ColorName, ThemeColor>,
}Expand description
A theme or color scheme represents a homogeneous combination of colors to applly to an application.
Each color scheme must have a unique name that identifies it.
The default Theme has no defined colors and has is_system set to
true to indicate that it’s a theme that follows the system wide
color scheme.
Fields
name: StringUnique name for the theme
is_system: boolIndicates that the Theme has no colors set and therefore follows
the system wide color scheme.
colors: HashMap<ColorName, ThemeColor>Implementations
Sourceimpl Theme
impl Theme
pub fn new_from_iter<I: IntoIterator<Item = (ColorName, ThemeColor)>>( name: String, colors: I, ) -> Self
pub fn new(name: String, colors: HashMap<ColorName, ThemeColor>) -> Self
pub fn to_css(&self, variant: ThemeColorVariant) -> String
pub fn get_provider(&self, variant: ThemeColorVariant) -> CssProvider
pub fn action_row(&self) -> ActionRow
Sourcepub fn default_themes() -> Vec<Self>
pub fn default_themes() -> Vec<Self>
Returns a list of built-in themes. Without any additional feature flags this will return an empty list.